@@ -4,7 +4,9 @@ from pyspark.sql import DataFrame, Column
 from pyspark.sql.functions import lpad
 
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
-from spark_auto_mapper.type_definitions.wrapper_types import AutoMapperColumnOrColumnLikeType
+from spark_auto_mapper.type_definitions.wrapper_types import (
+    AutoMapperColumnOrColumnLikeType,
+)
 
 
 class AutoMapperLPadDataType(AutoMapperTextLikeBase):
@@ -12,9 +14,8 @@ class AutoMapperLPadDataType(AutoMapperTextLikeBase):
     Returns column value, left-padded with pad to a length of length. If column value is longer than length,
     the return value is shortened to length characters.
     """
-    def __init__(
-        self, column: AutoMapperColumnOrColumnLikeType, length: int, pad: str
-    ):
+
+    def __init__(self, column: AutoMapperColumnOrColumnLikeType, length: int, pad: str):
         super().__init__()
 
         self.column: AutoMapperColumnOrColumnLikeType = column
@@ -29,6 +30,6 @@ class AutoMapperLPadDataType(AutoMapperTextLikeBase):
                 source_df=source_df, current_column=current_column
             ),
             len=self.length,
-            pad=self.pad
+            pad=self.pad,
         )
         return column_spec
