@@ -1,6 +1,7 @@
 from typing import Dict
 
 from pyspark.sql import SparkSession, Column, DataFrame
+
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import col, lit
 
@@ -12,9 +13,10 @@ def test_auto_mapper_boolean(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran', "0"),
-            (2, 'Vidal', 'Michael', "1"),
-        ], ['member_id', 'last_name', 'first_name', "my_age"]
+            (1, "Qureshi", "Imran", "0"),
+            (2, "Vidal", "Michael", "1"),
+        ],
+        ["member_id", "last_name", "first_name", "my_age"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -31,16 +33,16 @@ def test_auto_mapper_boolean(spark_session: SparkSession) -> None:
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert str(sql_expressions["age"]
-               ) == str(col("b.my_age").cast("boolean").alias("age"))
-    assert str(sql_expressions["is_active"]
-               ) == str(lit("False").cast("boolean").alias("is_active"))
+    assert str(sql_expressions["age"]) == str(
+        col("b.my_age").cast("boolean").alias("age")
+    )
+    assert str(sql_expressions["is_active"]) == str(
+        lit("False").cast("boolean").alias("is_active")
+    )
 
     result_df: DataFrame = mapper.transform(df=df)
 
@@ -48,14 +50,24 @@ def test_auto_mapper_boolean(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1").select(
-        "age",
-        "is_active",
-    ).collect()[0][:] == (False, False)
-    assert result_df.where("member_id == 2").select(
-        "age",
-        "is_active",
-    ).collect()[0][:] == (True, False)
+    assert (
+        result_df.where("member_id == 1")
+        .select(
+            "age",
+            "is_active",
+        )
+        .collect()[0][:]
+        == (False, False)
+    )
+    assert (
+        result_df.where("member_id == 2")
+        .select(
+            "age",
+            "is_active",
+        )
+        .collect()[0][:]
+        == (True, False)
+    )
 
     assert dict(result_df.dtypes)["age"] == "boolean"
     assert dict(result_df.dtypes)["is_active"] == "boolean"
