@@ -3,20 +3,19 @@ import os
 import shutil
 import random
 import string
-from os import path
 
 import pytest
 from _pytest.fixtures import FixtureRequest
 from pyspark.sql import SparkSession
 
 # make sure env variables are set correctly
-if 'SPARK_HOME' not in os.environ:
-    os.environ['SPARK_HOME'] = '/usr/local/opt/spark'
+if "SPARK_HOME" not in os.environ:
+    os.environ["SPARK_HOME"] = "/usr/local/opt/spark"
 
 
 def quiet_py4j() -> None:
-    """ turn down spark logging for the test context """
-    logger = logging.getLogger('py4j')
+    """turn down spark logging for the test context"""
+    logger = logging.getLogger("py4j")
     logger.setLevel(logging.ERROR)
 
 
@@ -66,35 +65,32 @@ def clean_close(session: SparkSession) -> None:
 
 def get_random_string(length: int) -> str:
     letters = string.ascii_lowercase
-    result_str = ''.join(random.choice(letters) for _ in range(length))
+    result_str = "".join(random.choice(letters) for _ in range(length))
     return result_str
 
 
 @pytest.fixture(scope="session")
 def spark_session(request: FixtureRequest) -> SparkSession:
     # make sure env variables are set correctly
-    if 'SPARK_HOME' not in os.environ:
-        os.environ['SPARK_HOME'] = '/usr/local/opt/spark'
+    if "SPARK_HOME" not in os.environ:
+        os.environ["SPARK_HOME"] = "/usr/local/opt/spark"
 
     clean_spark_dir()
-
     master = "local[2]"
-    # master: str = "spark://localhost:7077"
-    if not path.exists("/Applications/Docker.app"):
-        master = "local[2]"
-        print(f"++++++ Running on local spark: {master} ++++")
-    else:
-        print(f"++++++ Running on docker spark: {master} ++++")
 
-    session = SparkSession.builder.appName(f"pytest-pyspark-local-testing-{get_random_string(4)}"). \
-        master(master). \
-        config("spark.ui.showConsoleProgress", "false"). \
-        config("spark.sql.shuffle.partitions", "2"). \
-        config("spark.default.parallelism", "4"). \
-        config("spark.driver.bindAddress", "127.0.0.1"). \
-        config("spark.sql.broadcastTimeout", "2400"). \
-        enableHiveSupport(). \
-        getOrCreate()
+    session = (
+        SparkSession.builder.appName(
+            f"pytest-pyspark-local-testing-{get_random_string(4)}"
+        )
+        .master(master)
+        .config("spark.ui.showConsoleProgress", "false")
+        .config("spark.sql.shuffle.partitions", "2")
+        .config("spark.default.parallelism", "4")
+        .config("spark.driver.bindAddress", "127.0.0.1")
+        .config("spark.sql.broadcastTimeout", "2400")
+        .enableHiveSupport()
+        .getOrCreate()
+    )
 
     request.addfinalizer(lambda: clean_close(session))
     quiet_py4j()
@@ -104,28 +100,24 @@ def spark_session(request: FixtureRequest) -> SparkSession:
 @pytest.fixture(scope="function")
 def spark_session_per_function(request: FixtureRequest) -> SparkSession:
     # make sure env variables are set correctly
-    if 'SPARK_HOME' not in os.environ:
-        os.environ['SPARK_HOME'] = '/usr/local/opt/spark'
+    if "SPARK_HOME" not in os.environ:
+        os.environ["SPARK_HOME"] = "/usr/local/opt/spark"
 
     clean_spark_dir()
 
-    master: str = "spark://spark:7077"
     master = "local[2]"
-    if not path.exists("/Applications/Docker.app"):
-        master = "local[2]"
-        print(f"++++++ Running on local spark: {master} ++++")
-    else:
-        print(f"++++++ Running on docker spark: {master} ++++")
 
-    session = SparkSession.builder.appName("pytest-pyspark-local-testing"). \
-        master(master). \
-        config("spark.ui.showConsoleProgress", "false"). \
-        config("spark.sql.shuffle.partitions", "2"). \
-        config("spark.default.parallelism", "4"). \
-        config("spark.driver.bindAddress", "127.0.0.1"). \
-        config("spark.sql.broadcastTimeout", "2400"). \
-        enableHiveSupport(). \
-        getOrCreate()
+    session = (
+        SparkSession.builder.appName("pytest-pyspark-local-testing")
+        .master(master)
+        .config("spark.ui.showConsoleProgress", "false")
+        .config("spark.sql.shuffle.partitions", "2")
+        .config("spark.default.parallelism", "4")
+        .config("spark.driver.bindAddress", "127.0.0.1")
+        .config("spark.sql.broadcastTimeout", "2400")
+        .enableHiveSupport()
+        .getOrCreate()
+    )
 
     request.addfinalizer(lambda: clean_close(session))
     quiet_py4j()
