@@ -1,6 +1,7 @@
 from typing import Dict
 
 from pyspark.sql import SparkSession, Column, DataFrame
+
 # noinspection PyUnresolvedReferences
 from pyspark.sql.functions import col, when
 from pyspark.sql.functions import lit
@@ -14,9 +15,10 @@ def test_automapper_if_regex(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran', "54"),
-            (2, 'Vidal', 'Michael', None),
-        ], ['member_id', 'last_name', 'first_name', "my_age"]
+            (1, "Qureshi", "Imran", "54"),
+            (2, "Vidal", "Michael", None),
+        ],
+        ["member_id", "last_name", "first_name", "my_age"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -32,22 +34,19 @@ def test_automapper_if_regex(spark_session: SparkSession) -> None:
             column=A.column("my_age"),
             check="5*",
             value=A.number(A.column("my_age")),
-            else_=A.number(A.text("100"))
+            else_=A.number(A.text("100")),
         )
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
     assert str(sql_expressions["age"]) == str(
-        when(col("b.my_age").rlike("5*"),
-             col("b.my_age").cast(LongType())).otherwise(
-                 lit("100").cast(StringType()).cast(LongType())
-             ).alias("age")
+        when(col("b.my_age").rlike("5*"), col("b.my_age").cast(LongType()))
+        .otherwise(lit("100").cast(StringType()).cast(LongType()))
+        .alias("age")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
@@ -56,9 +55,7 @@ def test_automapper_if_regex(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1").select("age"
-                                                    ).collect()[0][0] == 54
-    assert result_df.where("member_id == 2").select("age"
-                                                    ).collect()[0][0] == 100
+    assert result_df.where("member_id == 1").select("age").collect()[0][0] == 54
+    assert result_df.where("member_id == 2").select("age").collect()[0][0] == 100
 
     assert dict(result_df.dtypes)["age"] in ("int", "long", "bigint")
