@@ -1,20 +1,20 @@
 from typing import Dict
 
 from pyspark.sql import SparkSession, Column, DataFrame
-from pyspark.sql.functions import array, expr
+from pyspark.sql.functions import array, expr, filter
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.list import AutoMapperList
-from spark_auto_mapper.helpers.spark_higher_order_functions import filter
 
 
 def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
     # Arrange
     spark_session.createDataFrame(
         [
-            (1, 'Qureshi', 'Imran'),
-            (2, 'Vidal', 'Michael'),
-        ], ['member_id', 'last_name', 'first_name']
+            (1, "Qureshi", "Imran"),
+            (2, "Vidal", "Michael"),
+        ],
+        ["member_id", "last_name", "first_name"],
     ).createOrReplaceTempView("patients")
 
     source_df: DataFrame = spark_session.table("patients")
@@ -27,13 +27,11 @@ def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
         view="members",
         source_view="patients",
         keys=["member_id"],
-        drop_key_columns=False
+        drop_key_columns=False,
     ).columns(dst2=AutoMapperList(["address1"]))
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
@@ -47,7 +45,11 @@ def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
     result_df.printSchema()
     result_df.show()
 
-    assert result_df.where("member_id == 1"
-                           ).select("dst2").collect()[0][0][0] == "address1"
-    assert result_df.where("member_id == 2"
-                           ).select("dst2").collect()[0][0][0] == "address1"
+    assert (
+        result_df.where("member_id == 1").select("dst2").collect()[0][0][0]
+        == "address1"
+    )
+    assert (
+        result_df.where("member_id == 2").select("dst2").collect()[0][0][0]
+        == "address1"
+    )
